---
description: Docker Trusted Registry restore command reference.
keywords:
- docker, registry, restore, backup
menu:
  main:
    identifier: dtr_reference_restore
    parent: dtr_menu_reference
title: restore
---

# docker/dtr restore

Create a new DTR cluster from an existing backup

## Usage

```bash
$ docker run -i --rm docker/dtr \
  restore [command options] < backup.tar
```

## Description

This command performs a fresh installation of DTR, and reconfigures it
with configuration data from a tar file generated by the 'backup' command.
The command starts by installing DTR, restores the configurations
stored on etcd, and then restores the repository metadata stored
on RethinkDB.

This command does not restore Docker images. You should implement a separate
restore procedure for the Docker images stored in your registry, taking in
consideration whether your DTR installation is configured to store images on
the filesystem or using a cloud provider.

After restoring DTR, you can add more nodes to the DTR cluster with
the 'join' command.


| Option                     | Description                                                                                      |
|:---------------------------|:-------------------------------------------------------------------------------------------------|
| `--ucp-url`                | Specify the UCP controller URL [$UCP_URL]                                                        |
| `--ucp-username`           | Specify the UCP admin username [$UCP_USERNAME]                                                   |
| `--ucp-password`           | Specify the UCP admin password [$UCP_PASSWORD]                                                   |
| `--debug`                  | Enable debug mode, provides additional logging [$DEBUG]                                          |
| `--hub-username`           | Specify the Docker Hub username for pulling images [$HUB_USERNAME]                               |
| `--hub-password`           | Specify the Docker Hub password for pulling images [$HUB_PASSWORD]                               |
| `--http-proxy`             | Set the HTTP proxy for outgoing requests [$DTR_HTTP_PROXY]                                       |
| `--https-proxy`            | Set the HTTPS proxy for outgoing requests [$DTR_HTTPS_PROXY]                                     |
| `--no-proxy`               | Set the list of domains to not proxy to [$DTR_NO_PROXY]                                          |
| `--replica-http-port "0"`  | Specify the public HTTP port for the DTR replica [$REPLICA_HTTP_PORT]                            |
| `--replica-https-port "0"` | Specify the public HTTPS port for the DTR replica [$REPLICA_HTTPS_PORT]                          |
| `--log-protocol`           | The protocol for sending container logs: tcp, udp or internal. Default: internal [$LOG_PROTOCOL] |
| `--log-host`               | Endpoint to send logs to, required if --log-protocol is tcp or udp [$LOG_HOST]                   |
| `--log-level`              | Log level for container logs. Default: INFO [$LOG_LEVEL]                                         |
| `--dtr-load-balancer`      | Specify the domain name and port for the DTR load balancer [$DTR_LOAD_BALANCER]                  |
| `--ucp-insecure-tls`       | Disable TLS verification for UCP [$UCP_INSECURE_TLS]                                             |
| `--ucp-ca`                 | Use a PEM-encoded TLS CA certificate for UCP [$UCP_CA]                                           |
| `--ucp-node`               | Specify the host to install Docker Trusted Registry [$UCP_NODE]                                  |
| `--replica-id`             | Specify the replica Id. Must be unique per replica, leave blank for random [$DTR_REPLICA_ID]     |
| `--config-only`            | Backup/restore only the configurations of DTR and not the database [$DTR_CONFIG_ONLY]            |
