---
description: Stream a tar file on stdin containing all local UCP data volumes.
keywords:
- docker, ucp, backup, restore
menu:
  main:
    identifier: ucp_ref_restore
    parent: ucp_ref
title: restore
---

# docker/ucp id

Stream a tar file on stdin containing all local UCP data volumes.

## Usage

```bash
docker run --rm -i \
  --name ucp \
  -v /var/run/docker.sock:/var/run/docker.sock \
  docker/ucp \
  restore [command options] < backup.tar
```

## Description

This utility will restore all the contents in all the volumes on this
controller based on a tar file generated by the 'backup' command.  Any UCP
containers that are running will be stopped prior to restoring the data.
After the data is replaced, the containers will be restarted.

When restoring multiple controllers in an HA cluster, you must manually
stop all controller nodes you plan to restore first, then begin the
restore with the most recent controller backup first.  The cluster will
resume operation once 1/2+1 of the controllers have been restored.

WARNING: Any existing state on this node will be lost and replaced by
the contents of the backup.  To prevent accidental use, the "-id" flag
must be provided.

## Options

| Option           | Description                                                                                            |
|:-----------------|:-------------------------------------------------------------------------------------------------------|
| `--debug, -D`    | Enable debug mode                                                                                      |
| `--jsonlog`      | Produce json formatted output for easier parsing                                                       |
| `--id`           | The ID of the UCP instance to backup                                                                   |
| `--root-ca-only` | Restore only the root CA certificates and keys on this controller node (leaving all other data intact) |
| `--passphrase`   | Decrypt the tar file with the provided passphrase [$UCP_PASSPHRASE]                                    |
| `--interactive, -i` | Enable interactive mode. You will be prompted to enter all required information.                    |
